@@ -19,7 +19,7 @@ using namespace CEC;
 class CECController : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.plasma-remotecontrollers.CEC")
+    Q_CLASSINFO("D-Bus Interface", "org.kde.plasma.remotecontrollers.CEC")
 
 public:
     explicit CECController();
@@ -30,6 +30,10 @@ public:
 public Q_SLOTS:
     Q_SCRIPTABLE int sendNextKey();
     Q_SCRIPTABLE bool hdmiCecSupported();
+    Q_SCRIPTABLE bool sendKey(uchar, CEC::cec_logical_address address = CECDEVICE_TV);
+    Q_SCRIPTABLE bool powerOnDevices(CEC::cec_logical_address address = CECDEVICE_TV);
+    Q_SCRIPTABLE bool powerOffDevices(CEC::cec_logical_address address = CECDEVICE_BROADCAST);
+    Q_SCRIPTABLE bool makeActiveSource();
 
 Q_SIGNALS:
     void keyPress(int keyCode, bool pressed);
